@@ -1,25 +1,36 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+    Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "geo.h"
 
-#include <QDataStream>
-#include <QSharedData>
+#include <QtCore/QDataStream>
+#include <QtCore/QSharedData>
 
 using namespace KContacts;
 
-class Q_DECL_HIDDEN Geo::Private : public QSharedData
+class Geo::Private : public QSharedData
 {
 public:
     Private()
-        : mLatitude(91)
-        , mLongitude(181)
-        , mValidLatitude(false)
-        , mValidLongitude(false)
+        : mLatitude(91), mLongitude(181),
+          mValidLatitude(false), mValidLongitude(false)
     {
     }
 
@@ -130,11 +141,13 @@ Geo &Geo::operator=(const Geo &other)
 
 QString Geo::toString() const
 {
-    QString str = QLatin1String("Geo {\n");
-    str += QStringLiteral("  Valid: %1\n").
-           arg(isValid() ? QStringLiteral("true") : QStringLiteral("false"));
-    str += QStringLiteral("  Latitude: %1\n").arg(d->mLatitude);
-    str += QStringLiteral("  Longitude: %1\n").arg(d->mLongitude);
+    QString str;
+
+    str += QLatin1String("Geo {\n");
+    str += QString::fromLatin1("  Valid: %1\n").
+           arg(isValid() ? QLatin1String("true") : QLatin1String("false"));
+    str += QString::fromLatin1("  Latitude: %1\n").arg(d->mLatitude);
+    str += QString::fromLatin1("  Longitude: %1\n").arg(d->mLongitude);
     str += QLatin1String("}\n");
 
     return str;
@@ -149,13 +162,13 @@ void Geo::clear()
 QDataStream &KContacts::operator<<(QDataStream &s, const Geo &geo)
 {
     return s << geo.d->mLatitude << geo.d->mValidLatitude
-             << geo.d->mLongitude << geo.d->mValidLongitude;
+           << geo.d->mLongitude << geo.d->mValidLongitude;
 }
 
 QDataStream &KContacts::operator>>(QDataStream &s, Geo &geo)
 {
     s >> geo.d->mLatitude >> geo.d->mValidLatitude
-    >> geo.d->mLongitude >> geo.d->mValidLongitude;
+      >> geo.d->mLongitude >> geo.d->mValidLongitude;
 
     return s;
 }
