@@ -1,18 +1,31 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2002 Tobias Koenig <tokoe@kde.org>
+    Copyright (c) 2002 Tobias Koenig <tokoe@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "sound.h"
 
-#include <QDataStream>
-#include <QSharedData>
+#include <QtCore/QDataStream>
+#include <QtCore/QSharedData>
 
 using namespace KContacts;
 
-class Q_DECL_HIDDEN Sound::Private : public QSharedData
+class Sound::Private : public QSharedData
 {
 public:
     Private()
@@ -114,7 +127,7 @@ bool Sound::isIntern() const
 bool Sound::isEmpty() const
 {
     return
-        (d->mIntern && d->mData.isEmpty()) || (!d->mIntern && d->mUrl.isEmpty());
+        ((d->mIntern && d->mData.isEmpty()) || (!d->mIntern && d->mUrl.isEmpty()));
 }
 
 QString Sound::url() const
@@ -129,14 +142,16 @@ QByteArray Sound::data() const
 
 QString Sound::toString() const
 {
-    QString str = QLatin1String("Sound {\n");
-    str += QStringLiteral("  IsIntern: %1\n").
-           arg(d->mIntern ? QStringLiteral("true") : QStringLiteral("false"));
+    QString str;
+
+    str += QLatin1String("Sound {\n");
+    str += QString::fromLatin1("  IsIntern: %1\n").
+           arg(d->mIntern ? QLatin1String("true") : QLatin1String("false"));
     if (d->mIntern) {
-        str += QStringLiteral("  Data: %1\n").
+        str += QString::fromLatin1("  Data: %1\n").
                arg(QString::fromLatin1(d->mData.toBase64()));
     } else {
-        str += QStringLiteral("  Url: %1\n").arg(d->mUrl);
+        str += QString::fromLatin1("  Url: %1\n").arg(d->mUrl);
     }
     str += QLatin1String("}\n");
 
